@@ -15,17 +15,18 @@ def get_self_version(package):
     warnings.warn('unable to get local package version')
 
 
-def get_latest_version(package, source='pypi.tuna.tsinghua.edu.cn'):
+def get_latest_version(package, source='pypi.org'):
     pkginfo = get(f'https://{source}/pypi/{package}/json').json()
     return pkginfo['info']['version']
 
 
 try:
-    if get_self_version(package) != (latest := get_latest_version(package)):
+    latest = get_latest_version(package)
+    if get_self_version(package) != latest:
         warnings.warn(f'''
 You are not using the latest version of libxduauth({latest}).
 upgrade the package by running:
 `pip3 install --upgrade libxduauth`
-'''.strip())
+''')
 except:
     pass
